@@ -17,7 +17,7 @@ _basic_dict = dict()
 for importer, modname, ispkg in pkgutil.iter_modules(path=['glowworm']):
     if ispkg:
         continue
-    print(modname)
+    # print(modname)
     # 将包下的所有模块，逐个导入，并调用其中的函数
     if modname.startswith('__') or modname == 'main':
         continue
